summaryrefslogtreecommitdiffstats
path: root/generic
diff options
context:
space:
mode:
authorMiguel Sofer <miguel.sofer@gmail.com>2003-10-28 22:06:14 (GMT)
committerMiguel Sofer <miguel.sofer@gmail.com>2003-10-28 22:06:14 (GMT)
commitc340234f07c54a57bb2446e7993bb236cd206b49 (patch)
treed7892bf3faf9bcae5c2a73b1c02abeb867e3d691 /generic
parent9f75af18b6ee3a121bf025014fed5a65f15e81d2 (diff)
downloadtcl-c340234f07c54a57bb2446e7993bb236cd206b49.zip
tcl-c340234f07c54a57bb2446e7993bb236cd206b49.tar.gz
tcl-c340234f07c54a57bb2446e7993bb236cd206b49.tar.bz2
* generic/tclExecute.c (NEXT_INST macros): replaced macro variable
"result" by "resultHandling" to avoid confusion.
Diffstat (limited to 'generic')
-rw-r--r--generic/tclExecute.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/generic/tclExecute.c b/generic/tclExecute.c
index f794543..25a5cdc 100644
--- a/generic/tclExecute.c
+++ b/generic/tclExecute.c
@@ -11,7 +11,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclExecute.c,v 1.112 2003/10/21 20:42:04 dgp Exp $
+ * RCS: @(#) $Id: tclExecute.c,v 1.113 2003/10/28 22:06:14 msofer Exp $
*/
#include "tclInt.h"
@@ -140,15 +140,15 @@ long tclObjsShared[TCL_MAX_SHARED_OBJ_STATS] = { 0, 0, 0, 0, 0 };
* ARGUMENTS:
* pcAdjustment: how much to increment pc
* nCleanup: how many objects to remove from the stack
* result: 0 indicates no object should be pushed on the
* stack; otherwise, push objResultPtr. If (result < 0),
* objResultPtr already has the correct reference count.
*/
-#define NEXT_INST_F(pcAdjustment, nCleanup, result) \
+#define NEXT_INST_F(pcAdjustment, nCleanup, resultHandling) \
if (nCleanup == 0) {\
- if (result != 0) {\
- if ((result) > 0) {\
+ if (resultHandling != 0) {\
+ if ((resultHandling) > 0) {\
PUSH_OBJECT(objResultPtr);\
} else {\
*(++tosPtr) = objResultPtr;\
@@ -156,8 +156,8 @@ long tclObjsShared[TCL_MAX_SHARED_OBJ_STATS] = { 0, 0, 0, 0, 0 };
} \
pc += (pcAdjustment);\
goto cleanup0;\
- } else if (result != 0) {\
- if ((result) > 0) {\
+ } else if (resultHandling != 0) {\
+ if ((resultHandling) > 0) {\
Tcl_IncrRefCount(objResultPtr);\
}\
pc += (pcAdjustment);\
@@ -175,11 +175,11 @@ long tclObjsShared[TCL_MAX_SHARED_OBJ_STATS] = { 0, 0, 0, 0, 0 };
}\
}
-#define NEXT_INST_V(pcAdjustment, nCleanup, result) \
+#define NEXT_INST_V(pcAdjustment, nCleanup, resultHandling) \
pc += (pcAdjustment);\
cleanup = (nCleanup);\
- if (result) {\
- if ((result) > 0) {\
+ if (resultHandling) {\
+ if ((resultHandling) > 0) {\
Tcl_IncrRefCount(objResultPtr);\
}\
goto cleanupV_pushObjResultPtr;\
@@ -140,15 +140,15 @@ long tclObjsShared[TCL_MAX_SHARED_OBJ_STATS] = { 0, 0, 0, 0, 0 };
* pcAdjustment: how much to increment pc
* nCleanup: how many objects to remove from the stack
- * result: 0 indicates no object should be pushed on the
+ * resultHandling: 0 indicates no object should be pushed on the
* stack; otherwise, push objResultPtr. If (result < 0),
* objResultPtr already has the correct reference count.